--------------------------------------------------
--
--  AddOn: Atlas
--  Date: 6/10/2005
--  Author: Razark
--  Contact: loglow@gmail.com
--
--------------------------------------------------

Options = {
	AtlasAlpha = 1.0,
	AtlasLocked = false,
	AtlasButtonPosition = 268,
	AtlasButtonShown = true
};

ATLAS_VERSION = "v0.9.5";
ATLAS_TITLE = "Atlas";
ATLAS_SUBTITLE = "界面地图";
ATLAS_DESC = "浏览副本地图。";
ATLAS_VERS_TITLE = ATLAS_TITLE.." "..ATLAS_VERSION;

BINDING_HEADER_ATLAS_TITLE = ATLAS_TITLE;
BINDING_NAME_ATLAS_TOGGLE = "开启/关闭 "..ATLAS_TITLE;
BINDING_NAME_ATLAS_TOGGLE_OPTIONS = "选项";

ATLAS_SLASH_HELP = "help";
ATLAS_SLASH_TOGGLE = "toggle";
ATLAS_SLASH_BUTTON = "button";
ATLAS_SLASH_ANGLE = "angle";
ATLAS_SLASH_ALPHA = "alpha";

ATLAS_DROPDOWN_LIST = {
	{name = "阿塔哈卡神庙",	file = "TheTempleofAtal'Hakkar"},
	{name = "哀嚎洞穴",		file = "WailingCaverns"},
	{name = "奥达曼",			file = "Uldaman"},
	{name = "奥妮克希亚的巢穴",		file = "Onyxia'sLair"},
	{name = "厄运之槌 (北)",		file = "DireMaul(North)"},
	{name = "厄运之槌 (东)",		file = "DireMaul(East)"},
	{name = "厄运之槌 (西)",		file = "DireMaul(West)"},
	{name = "黑暗深渊",		file = "BlackfathomDeeps"},
	{name = "黑石深渊",		file = "BlackrockDepths"},
	{name = "黑石塔 (上层)",	file = "BlackrockSpire(Upper)"},
	{name = "监狱",			file = "TheStockade"},
	{name = "玛拉顿",			file = "Maraudon"},
	{name = "怒焰裂谷",		file = "RagefireChasm"},
	{name = "诺莫瑞根",			file = "Gnomeregan"},
	{name = "熔火之核",			file = "MoltenCore"},
	{name = "斯坦索姆",			file = "Stratholme"},
	{name = "死亡矿井",		file = "TheDeadmines"},
	{name = "剃刀高地",		file = "RazorfenDowns"},
	{name = "剃刀沼泽",		file = "RazorfenKraul"},
	{name = "通灵学院",			file = "Scholomance"},
	{name = "血色修道院",		file = "ScarletMonastery"},
	{name = "祖尔法拉克",			file = "Zul'Farrak"}
};

function Atlas_OnLoad()
	this:RegisterEvent("VARIABLES_LOADED");
	tinsert(UISpecialFrames, "AtlasFrame");
	UIPanelWindows["AtlasFrame"] = nil;
	AtlasFrame:RegisterForDrag("LeftButton");
	SLASH_ATLAS1 = "/atlas";
	SlashCmdList["ATLAS"] = function(msg)
		Atlas_SlashCommand(msg);
	end
end

function Atlas_OnEvent()
	if(event == "VARIABLES_LOADED") then

		Atlas_Refresh();
		AtlasOptions_Init();
		Atlas_UpdateLock();
		AtlasButton_UpdatePosition();
		Atlas_UpdateAlpha();

		---------------------
		-- support for Cosmos
		---------------------
		if(Cosmos_RegisterButton) then
			Cosmos_RegisterButton(
				ATLAS_VERS_TITLE,
				ATLAS_SUBTITLE,
				ATLAS_DESC,
				"Interface\\Icons\\INV_Misc_Map_01",
				Atlas_Toggle);
		end

		-----------------------
		-- support for myAddOns
		-----------------------
 		if(myAddOnsList) then
			myAddOnsList.Atlas = {
				name = ATLAS_TITLE,
				description = ATLAS_DESC,
				version = ATLAS_VERSION,
				category = MYADDONS_CATEGORY_MAP,
				frame = "AtlasFrame",
				optionsframe = 'AtlasOptionsFrame'};
		end
	end
end

function Atlas_ToggleLock()
	if(Options.AtlasLocked) then
		Options.AtlasLocked = false;
		Atlas_UpdateLock();
	else
		Options.AtlasLocked = true;
		Atlas_UpdateLock();
	end
end

function Atlas_UpdateLock()
	if(Options.AtlasLocked) then
		AtlasLockNorm:SetTexture("Interface\\AddOns\\Atlas\\Images\\LockButton-Locked-Up");
		AtlasLockPush:SetTexture("Interface\\AddOns\\Atlas\\Images\\LockButton-Locked-Down");
	else
		AtlasLockNorm:SetTexture("Interface\\AddOns\\Atlas\\Images\\LockButton-Unlocked-Up");
		AtlasLockPush:SetTexture("Interface\\AddOns\\Atlas\\Images\\LockButton-Unlocked-Down");
	end
end

function Atlas_StartMoving()
	if(not Options.AtlasLocked) then
		AtlasFrame:StartMoving();
	end
end

function Atlas_OnShow()
	local currentZone = GetRealZoneText();
	local currentMapID = UIDropDownMenu_GetSelectedID(AtlasFrameDropDown);
	if(currentZone ~= ATLAS_DROPDOWN_LIST[currentMapID].name) then
		for i = 1, getn(ATLAS_DROPDOWN_LIST), 1 do
			if(currentZone == ATLAS_DROPDOWN_LIST[i].name) then
				UIDropDownMenu_Initialize(AtlasFrameDropDown, AtlasFrameDropDown_Initialize);
				UIDropDownMenu_SetSelectedID(AtlasFrameDropDown, i);
				Atlas_Refresh();
			end
		end
	end
end

function Atlas_SlashCommand(msg)
	if(msg == "options") then
		AtlasOptions_Toggle();
	else
		Atlas_Toggle();
	end
end

function Atlas_UpdateAlpha()
	AtlasFrame:SetAlpha(Options.AtlasAlpha);
end

function Atlas_Toggle()
	if(AtlasFrame:IsVisible()) then
		HideUIPanel(AtlasFrame);
	else
		ShowUIPanel(AtlasFrame);
	end
end

function Atlas_Refresh()
	local currentID = UIDropDownMenu_GetSelectedID(AtlasFrameDropDown);
	AtlasMap:ClearAllPoints();
	AtlasMap:SetWidth(512);
	AtlasMap:SetHeight(512);
	AtlasMap:SetPoint("TOPLEFT", "AtlasFrame", "TOPLEFT", 14, -71);
	AtlasMap:SetTexture("Interface\\AddOns\\Atlas\\Images\\"..ATLAS_DROPDOWN_LIST[currentID].file);
end

function AtlasFrameDropDown_Initialize()
	local info;
	for i = 1, getn(ATLAS_DROPDOWN_LIST), 1 do
		info = { };
		info.text = ATLAS_DROPDOWN_LIST[i].name;
		info.func = AtlasFrameDropDownButton_OnClick;
		UIDropDownMenu_AddButton(info);
	end
end

function AtlasFrameDropDown_OnLoad()
	UIDropDownMenu_Initialize(AtlasFrameDropDown, AtlasFrameDropDown_Initialize);
	UIDropDownMenu_SetSelectedID(AtlasFrameDropDown, 1);
	UIDropDownMenu_SetWidth(150);
end

function AtlasFrameDropDownButton_OnClick()
	local oldID = UIDropDownMenu_GetSelectedID(AtlasFrameDropDown);
	UIDropDownMenu_SetSelectedID(AtlasFrameDropDown, this:GetID());
	if(oldID ~= this:GetID()) then
		Atlas_Refresh();
	end
end
